
# AI RPA Library

Library ini merupakan pelengkap library untuk RPA dengan robotframeworks, untuk fitur atau fungsi yang ada pada library ini adalah sebagai berikut:

1. Read Config
    digunakan untuk melakukan membaca file konfigurasi dengan format dictionary pada dengan nama file config.json serta fungsi ini juga menambahkan dictionary yang belum ada pada file config.json dengan input parameter json object.
2. Timeout
    digunakan untuk memberikan waktu timeout pada sebuah proses yang akan dilanjutkan, proses timeout ini memanfaatkan multiprocessing module python.
3. Send Email
    digunakan untuk mengirimkan email via api

